@@ -56,8 +56,8 @@ class AnalysisForm(forms.Form):
     else:
         NEIGH_DEN_CHOICES = (('N','None'),
                             ('B','Neighbourhood based on Buckeye words'))
-    FETCH_CHOICES = (('PrevSemPred','PrevSemPred'),
-                    'FollSemPred','FollSemPred')
+    #FETCH_CHOICES = (('PrevSemPred','PrevSemPred'),
+    #                'FollSemPred','FollSemPred')
     measure = forms.CharField(label='Measure')
     DispersionFromAH = forms.BooleanField(initial=False,required=False,label="Dispersion from a speaker's AH tokens")
     measure.widget = forms.Select(choices=M_CHOICES)
@@ -84,8 +84,8 @@ class AnalysisForm(forms.Form):
     numSylls = forms.BooleanField(initial=True,required=False,label='Number of syllables')
     prev_sem_pred = forms.BooleanField(initial=True,required=False,label='Previous semantic predictability')
     foll_sem_pred = forms.BooleanField(initial=True,required=False,label='Following semantic predictability')
-    force_fetch = forms.CharField(label='Force fetch')
-    force_fetch.widget = forms.CheckboxSelectMultiple(choices=FETCH_CHOICES)
+    #force_fetch = forms.CharField(label='Force fetch')
+    #force_fetch.widget = forms.CheckboxSelectMultiple(choices=FETCH_CHOICES)
 
 
 
