@@ -918,6 +918,16 @@ class WordToken(models.Model):
             rate = 0.0
         return rate
 
+    def getPrevDistToPause(self):
+        if self.afterPause():
+            return 0.0
+        return sum([x.getDuration() for x in self.getPreviousContext()])
+
+    def getFollDistToPause(self):
+        if self.beforePause():
+            return 0.0
+        return sum([x.getDuration() for x in self.getFollowingContext()])
+
     def getPreviousCondProb(self):
         if self.afterPause():
             return 0.0
@@ -1158,6 +1168,69 @@ class WordToken(models.Model):
             self.Output = {x: self.Output[x] for x in self.Output if x != f}
             self.save()
 
+    def get_details(self):
+        if self.WordType.isWord():
+            sp,bp = self.WordType.getPhonoProb()
+            out = {'Preceding': self.getPreviousContext(),
+                    'Following': self.getFollowingContext(),
+                    'Word': str(self.WordType),
+                    'NFormants': self.Dialog.Speaker.NumFormants,
+                    'Ceiling': self.Dialog.Speaker.Ceiling,
+                    'Token': self.pk,
+                    'Contextual':{
+                                'Previous conditional probability': self.getPreviousCondProb(),
+                                'Following conditional probability': self.getFollowingCondProb(),
+                                'Previous speaking rate': self.getPreviousSpeakingRate(),
+                                'Following speaking rate': self.getFollowingSpeakingRate(),
+                                'Previous distance to pause': self.getPrevDistToPause(),
+                                'Following distance to pause': self.getFollDistToPause(),
+                                'Previous semantic predictability': self.getPrevSemPred(),
+                                'Following semantic predictability':self.getFollSemPred()},
+                    'Lexical':{'Word': str(self.WordType),
+                            'Underlying representation': self.WordType.getUR(),
+                            'Buckeye frequency': self.WordType.getFreq(),
+                            'Buckeye single-phone probability': sp,
+                            'Buckeye bi-phone probability': bp,
+                            'Buckeye neighbourhood density': self.WordType.getND(),
+                            'Buckeye frequency-weighted neighbourhood density': self.WordType.getFWND(),
+                            'Stress vowel': self.WordType.getStressVowel()},
+                    'Token':{'Dialog': str(self.Dialog),
+                            'Surface representation': self.getSR(),
+                            'Buckeye category': str(self.Category),
+                            'Stress vowel F1': self.getStrF1(),
+                            'Stress vowel F2': self.getStrF2(),
+                            'Repetitions': self.getRepetitions(),
+                            'Given': self.getRecentRepetition()},
+                    'Speaker':{'Speaker': str(self.Dialog.Speaker),
+                            'Gender': self.Dialog.Speaker.Gender,
+                            'Age': self.Dialog.Speaker.Age,
+                            'Number of formants': self.Dialog.Speaker.NumFormants,
+                            'Formant ceiling': self.Dialog.Speaker.Ceiling,
+                            'Vowel center': self.Dialog.Speaker.getCenter(),
+                            'Average speaking rate': self.Dialog.Speaker.getAvgSpeakingRate()}}
+        else:
+            out = {'Preceding': self.getPreviousContext(),
+                    'Following': self.getFollowingContext(),
+                    'Word': str(self.WordType),
+                    'NFormants': self.Dialog.Speaker.NumFormants,
+                    'Ceiling': self.Dialog.Speaker.Ceiling,
+                    'Token': self.pk,
+                    'Contextual':{'Previous speaking rate': self.getPreviousSpeakingRate(),
+                                'Following speaking rate': self.getFollowingSpeakingRate(),
+                                'Previous distance to pause': self.getPrevDistToPause(),
+                                'Following distance to pause': self.getFollDistToPause(),},
+                'Token':{'Dialog': str(self.Dialog),
+                            'Buckeye category': str(self.Category)},
+                'Speaker':{'Speaker': str(self.Dialog.Speaker),
+                            'Gender': self.Dialog.Speaker.Gender,
+                            'Age': self.Dialog.Speaker.Age,
+                            'Number of formants': self.Dialog.Speaker.NumFormants,
+                            'Formant ceiling': self.Dialog.Speaker.Ceiling,
+                            'Vowel center': self.Dialog.Speaker.getCenter(),
+                            'Average speaking rate': self.Dialog.Speaker.getAvgSpeakingRate()}}
+
+        return out
+
 
 #class SynSemCase(models.Model):
     #verb = models.ForeignKey(WordToken)
